//Copyright (c) 1997 The Open Group
//
//Permission to use, copy, modify, and distribute this software and its documentation for
//any purpose and without fee is hereby granted, provided that the above copyright notice
//appears in all copies and that both the copyright notice and this permission notice
//appear in supporting documentation, and that the name of ("TOG") or The Open Group not
//be used in advertising or publicity pertaining to distribution of the software without
//specific, written prior permission.
//
//THE OPEN GROUP DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
//IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT
//SHALL TOG BE LIABLE FOR ANY SPECIAL, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
//WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN ACTION OF CONTRACT,
//NEGLIGENCE, OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
//PERFORMANCE OF THIS SOFTWARE. 

/* 
 * ButtonDialog
 * by Bill la Forge
 * http://www.opengroup.org/~laforge
 */
  
package ORG.opengroup.awt;
import ORG.opengroup.misc.*;
import java.awt.*;
import java.awt.event.*;

/**
 * A Dialog which displays a row of buttons.
 */
public class ButtonDialog extends Dialog
{
	private Button button[];
	private int selection;

	class Go implements ActionListener
	{
		private int sel;

		public Go(int psel)
		{
			sel=psel;
		}

		public void actionPerformed(ActionEvent e)
		{
			selection=sel;
			setVisible(false);
			dispose();
		}
	}

	/**
	 * Construct the dialog. To allow subclassing, show() is not called.
	 * @param parent		The parent frame.
	 * @param title		Window title.
	 * @param x			x-location of the dialog.
	 * @param y			y-location of the dialog.
	 * @param buttonLabels	Button labels, one button per line.
	 */
	public ButtonDialog(
		Frame parent, 
		String title, 
		int x, 
		int y,
		String buttonLabels)
	{
		super(parent,title,true);
		setLocation(x,y);
		enableEvents(WindowEvent.WINDOW_CLOSING);
		selection=-1;
		setLayout(new BorderLayout(5,5));
		Panel p=new Panel();
		p.setLayout(new FlowLayout(FlowLayout.CENTER,5,5));
		Line ln=new Line(buttonLabels);
		int l=ln.getHeight();
		button=new Button[l];
		int i;
		for (i=0;i<l;++i)
		{
			button[i]=new Button((String)ln.nextElement());
			button[i].addActionListener(new ButtonDialog.Go(i));
			p.add(button[i]);
		}
		add("South",p);
		pack();
	}

	protected void processWindowEvent(WindowEvent e)
	{
		if (e.getID()==WindowEvent.WINDOW_CLOSING)
			dispose();
		super.processWindowEvent(e);
	}

	/**
	 * Returns the button selected, starting at 0.
	 * If the dialog was closed without a selection, -1 is returned.
	 */
	public int getSelection()
	{
		return selection;
	}
}
