//Copyright (c) 1997 The Open Group
//
//Permission to use, copy, modify, and distribute this software and its documentation for
//any purpose and without fee is hereby granted, provided that the above copyright notice
//appears in all copies and that both the copyright notice and this permission notice
//appear in supporting documentation, and that the name of ("TOG") or The Open Group not
//be used in advertising or publicity pertaining to distribution of the software without
//specific, written prior permission.
//
//THE OPEN GROUP DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL
//IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT
//SHALL TOG BE LIABLE FOR ANY SPECIAL, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
//WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN ACTION OF CONTRACT,
//NEGLIGENCE, OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
//PERFORMANCE OF THIS SOFTWARE. 

/* 
 * ORG.opengroup.moabatch.ReadyThread version 0.1
 * by Bill la Forge
 * http://www.opengroup.org/~laforge
 */

package ORG.opengroup.beans;

import java.beans.*;
import java.io.*;

/**
 * ReadyThread starts running when an instance is constructed and
 * when an instance is deserialized.
 * However, ReadyThread does not start running at "desgin time".
 * <p>
 * The intent here is that a Bean will have a nested class which 
 * extends ReadyThread, overriding the run method. For example:
 * <pre>
 * public class TestReadyThread implements Serializable
 * {
 *     Thread runner= new ReadyThread()
 *     {
 *         public void run()
 *         {
 *             System.out.println("Blip!");
 *         }
 *     };
 * }
 * </pre>
 */
public class ReadyThread extends Thread implements Serializable
{
    public ReadyThread()
    {
        if (!Beans.isDesignTime())
            start();
    }

    private void writeObject(ObjectOutputStream s)
        throws IOException
    {
        s.defaultWriteObject();
    }

    private void readObject(ObjectInputStream s)
        throws ClassNotFoundException, IOException 
    {
        s.defaultReadObject();
        if (!Beans.isDesignTime())
            start();
    }
}  
